/*
  TLC59282
  Tests of the TLC59282

  FIXES TODO:
    Move IR_IN to PC0
    
*/

#include <SPI.h>

const int HALL  =  2; // PD2
const int BLANK =  8; // PB0 - pink wire
const int LAT   =  9; // PB1 - blue wire
//const int SS    = 10; // PB2 - Slave select, not used but must be set as output 
const int SIN   = 11; // PB3 - MOSI - white wire (probably not used directly)
const int SCLK  = 13; // PB5 - SCLK - purple wire (probably not used directly)

const int HALL_INT = 0; // Hall effect interrupt 0

int detected = 0;

void hallStart(void) {
  detected = 1;
}


void setup() {
  Serial.begin(9600);
  
  digitalWrite(LAT, LOW);
  pinMode(LAT, OUTPUT);     

  digitalWrite(BLANK, HIGH);
  pinMode(BLANK, OUTPUT);     

  pinMode(HALL, INPUT_PULLUP);
  
  attachInterrupt(HALL_INT, hallStart, FALLING);
  
  SPI.begin();
  SPI.setDataMode(SPI_MODE0);
  SPI.setBitOrder(LSBFIRST);
  SPI.setClockDivider(SPI_CLOCK_DIV2); // Datasheet says 35 MHz max, so 8 MHz is fine

  Serial.println("TLC59282 test setup complete.");
}

#if 0

void loop() {
  int output = 0;
  
  if (detected)
  {
    output = 0xFF;
    detected = 0;
  }
  
  // Blank the LEDS
  digitalWrite(BLANK, HIGH);

  int data;
  
  data = SPI.transfer(output);
//  Serial.print("Read byte: 0x");
//  Serial.print(data, HEX);
//  Serial.println("");
  
  data = SPI.transfer(~output);
//  Serial.print("Read byte: 0x");
//  Serial.print(data, HEX);
//  Serial.println("");
  
  // Latch the data
  digitalWrite(LAT, HIGH);
  digitalWrite(LAT, LOW);
  
  // Unblank the LEDS
  digitalWrite(BLANK, LOW);
  
  delay(100);
}

#else
void loop() {
  static int i = 0;
  
//  Serial.println("Writing LEDs.");
  
  // Blank the LEDS
  digitalWrite(BLANK, HIGH);

  int data;
  
  data = SPI.transfer(i & 0xFF);
//  Serial.print("Read byte: 0x");
//  Serial.print(data, HEX);
//  Serial.println("");
  
  data = SPI.transfer((i & 0xFF00) >> 8);
//  Serial.print("Read byte: 0x");
//  Serial.print(data, HEX);
//  Serial.println("");
  
  // Latch the data
  digitalWrite(LAT, HIGH);
  digitalWrite(LAT, LOW);
  
  // Unblank the LEDS
  digitalWrite(BLANK, LOW);
  
  delay(10);

#if 1
  i = i << 1;
  if (i == 0)
  {
    i = 1;
  }
#else
  i++;
#endif
}
#endif
